@@ -1,7 +1,7 @@
 #
 # This file is part of App-SpreadRevolutionaryDate
 #
-# This software is Copyright (c) 2019-2024 by Gérald Sédrati.
+# This software is Copyright (c) 2019-2025 by Gérald Sédrati.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::Telechat;
-$App::SpreadRevolutionaryDate::MsgMaker::Telechat::VERSION = '0.39';
+$App::SpreadRevolutionaryDate::MsgMaker::Telechat::VERSION = '0.40';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message with Téléchat date
 
 use Moose;
@@ -408,7 +408,7 @@ sub compute {
   );
   my @telechat_days = ('Lourdi', 'Pardi', 'Morquidi', 'Jourdi', 'Dendrevi', 'Sordi', 'Mitanche');
 
-  my $today = DateTime->now;
+  my $today = DateTime->now(time_zone => 'Europe/Paris');
   my $day_name = $telechat_days[$today->day_of_week_0];
   my $feast = $telechat_calendar{sprintf("%02d", $today->day).sprintf("%02d", $today->month)};
   my $feast_gender = $feast->[2] eq 'm' ? 'Saint' : 'Sainte';
@@ -449,7 +449,7 @@ App::SpreadRevolutionaryDate::MsgMaker::Telechat - MsgMaker class for L<App::Spr
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 METHODS
 
@@ -513,7 +513,7 @@ Gérald Sédrati <gibus@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019-2024 by Gérald Sédrati.
+This software is Copyright (c) 2019-2025 by Gérald Sédrati.
 
 This is free software, licensed under:
 
